@@ -14,9 +14,9 @@ impl_vector!(Vector5 { x, y, z, w, v }, 5);
 
 
 fn main() {
-    println!("Vector Name: {}", Vector5::<()>::NAME);
-    println!("Vector Length: {}", Vector5::<()>::LEN);
-    println!("Vector Size: {}", Vector5::<i32>::SIZE);
+    println!("Vector5 Name: {}", Vector5::<()>::NAME);
+    println!("Vector5 Length: {}", Vector5::<()>::LEN);
+    println!("Vector5<i32> Size: {}", Vector5::<i32>::SIZE);
     
     let vector = Vector5::new(1, 2, 3, 4, 5);
 
@@ -25,7 +25,7 @@ fn main() {
     println!("Vector as Array: {:?}", vector.to_array());
     println!("Vector as Vec: {:?}", vector.to_vec());
 
-    let mut sum= 0;
+    let mut sum = 0;
     for i in vector { sum += i; }
     println!("Vector Sum: {}", sum);
 }
\ No newline at end of file
